@@ -191,6 +191,8 @@ class IP:
         self.vproj_libs                 = []
         self.vproj_vlog                 = ""
         self.vproj_vhdl                 = ""
+        self.targets                    = {}
+        self.has_targets                = False
     
     def parse_from_ip_yml(self):
         ip_yml_path = self.path + "/ip.yml"
@@ -334,6 +336,36 @@ class IP:
                     else:
                         raise Exception(f"Malformed dut section")
                 
+                if 'targets' in yml:
+                    if not type(yml['targets']) is dict:
+                        raise Exception(f"'targets' is not a dictionary")
+                    else:
+                        self.has_targets = True
+                        found_default_target = False
+                        for target in yml['targets']:
+                            target_name = target.strip().lower()
+                            cur_target = Target(target_name)
+                            if cur_target.is_default:
+                                found_default_target = True
+                            self.targets[target_name] = cur_target
+                            if 'cmp' in yml['targets'][target]:
+                                if type(yml['targets'][target]['cmp']) is dict:
+                                    for arg in yml['targets'][target]['cmp']:
+                                        cur_arg = str(yml['targets'][target]['cmp'][arg]).strip()
+                                        cur_target.cmp_args[arg.strip()] = cur_arg
+                            if 'elab' in yml['targets'][target]:
+                                if type(yml['targets'][target]['elab']) is dict:
+                                    for arg in yml['targets'][target]['elab']:
+                                        cur_arg = str(yml['targets'][target]['elab'][arg]).strip()
+                                        cur_target.elab_args[arg.strip()] = cur_arg
+                            if 'sim' in yml['targets'][target]:
+                                if type(yml['targets'][target]['sim']) is dict:
+                                    for arg in yml['targets'][target]['sim']:
+                                        cur_arg = str(yml['targets'][target]['sim'][arg]).strip()
+                                        cur_target.sim_args[arg.strip()] = cur_arg
+                        if not found_default_target:
+                            raise Exception(f"Did not find default target")
+                
                 if self.is_licensed == True:
                     if not ((self.vendor == "datum") and (self.name == "uvml_mio_lic")):
                         dep_model = Dependency(self, "datum/uvml_mio_lic", "^")
@@ -426,6 +458,19 @@ class IP:
             for dep in yml['dependencies']:
                 dep_model = Dependency(self, dep, yml['dependencies'][dep])
                 self.dependencies.append(dep_model)
+            
+            if 'targets' in yml:
+                self.has_targets = True
+                for target in yml['targets']:
+                    cur_target = Target(target)
+                    self.targets[target] = cur_target
+                    for arg in yml['targets'][target]['cmp']:
+                        cur_target.cmp_args[arg] = yml['targets'][target]['cmp'][arg]
+                    for arg in yml['targets'][target]['elab']:
+                        cur_target.elab_args[arg] = yml['targets'][target]['elab'][arg]
+                    for arg in yml['targets'][target]['sim']:
+                        cur_target.sim_args[arg] = yml['targets'][target]['sim'][arg]
+            
             self.is_new = False
             return True
         except Exception as e:
@@ -521,6 +566,21 @@ class IP:
         dict['dependencies'] = {}
         for dep in self.dependencies:
             dict['dependencies'][f"{dep.vendor}/{dep.target_ip}"] = dep.semver
+        
+        if self.has_targets:
+            dict['targets'] = {}
+            for target in self.targets:
+                dict['targets'][target] = {}
+                dict['targets'][target]['cmp' ] = {}
+                dict['targets'][target]['elab'] = {}
+                dict['targets'][target]['sim' ] = {}
+                for arg in self.targets[target].cmp_args:
+                    dict['targets'][target]['cmp'][arg] = self.targets[target].cmp_args[arg]
+                for arg in self.targets[target].elab_args:
+                    dict['targets'][target]['elab'][arg] = self.targets[target].elab_args[arg]
+                for arg in self.targets[target].sim_args:
+                    dict['targets'][target]['sim'][arg] = self.targets[target].sim_args[arg]
+        
         return dict
     
     def integrity_check(self):
@@ -684,6 +744,19 @@ class Dependency:
             self.semver = self.target_ip_model.version
 
 
+class Target:
+    """IP Target Model"""
+    
+    def __init__(self, name):
+        self.name = name
+        self.is_default = False
+        if (self.name == "") or (self.name == "default"):
+            self.is_default = True
+        self.cmp_args  = {}
+        self.elab_args = {}
+        self.sim_args  = {}
+
+
 def check_ip(vendor, name):
     if vendor == "":
         ip = get_anon_ip(name)
