@@ -827,20 +827,24 @@ def do_simulate(ip, sim_job, wd):
     
     plus_args["__MIO_TOKEN"] = user.login()
     
+    if sim_job.target_name != "default":
+        target_str = f"_{sim_job.target_name}"
+    else:
+        target_str = f""
     if sim_job.simulator == common.simulators_enum.METRICS:
         mdc_regr_results_dir = cfg.temp_path + "/mdc_regr"
         mdc_sim_results_dir  = cfg.temp_path + "/mdc_results"
         common.create_dir(mdc_regr_results_dir)
         common.create_dir(mdc_sim_results_dir )
         if sim_job.is_regression:
-            common.create_dir       (mdc_regr_results_dir + "/" + ip.name + "__" + sim_job.regression_name + "__" + sim_job.regression_timestamp)
-            mdc_tests_results_path = ".mio/temp/mdc_regr/"      + ip.name + "__" + sim_job.regression_name + "__" + sim_job.regression_timestamp + "/" + test_result_dir
+            common.create_dir       (mdc_regr_results_dir + "/" + ip.name + target_str + "_" + sim_job.regression_name + "_" + sim_job.regression_timestamp)
+            mdc_tests_results_path = ".mio/temp/mdc_regr/"      + ip.name + target_str + "_" + sim_job.regression_name + "_" + sim_job.regression_timestamp + "/" + test_result_dir
         else:
             common.create_dir       (mdc_sim_results_dir + "/" + test_result_dir)
             mdc_tests_results_path = ".mio/temp/mdc_results/"  + test_result_dir
     if sim_job.is_regression:
-        common.create_dir   (cfg.regr_results_dir + "/" + ip.name + "__" + sim_job.regression_name + "__" + sim_job.regression_timestamp)
-        tests_results_path = cfg.regr_results_dir + "/" + ip.name + "__" + sim_job.regression_name + "__" + sim_job.regression_timestamp + "/" + test_result_dir
+        common.create_dir   (cfg.regr_results_dir + "/" + ip.name + target_str + "_" + sim_job.regression_name + "_" + sim_job.regression_timestamp)
+        tests_results_path = cfg.regr_results_dir + "/" + ip.name + target_str + "_" + sim_job.regression_name + "_" + sim_job.regression_timestamp + "/" + test_result_dir
     else:
         tests_results_path = cfg.sim_results_dir + "/" + test_result_dir
     
@@ -1701,6 +1705,7 @@ def log_sim_start_history(ip, sim_job, timestamp):
     cfg.job_history[ip_str]['simulation'].append({
         "type"                 : "start",
         "simulator"            : sim_str,
+        "target_name"          : sim_job.target_name,
         'timestamp'            : timestamp,
         'test_name'            : sim_job.test,
         'seed'                 : sim_job.seed,
@@ -1731,10 +1736,12 @@ def log_sim_end_history(ip, sim_job, timestamp_start, timestamp_end):
     entry = {
         "type"                 : "end",
         "simulator"            : sim_str,
+        "target_name"          : sim_job.target_name,
         'timestamp_start'      : timestamp_start,
         'timestamp_end'        : timestamp_end,
         'duration'             : duration,
         'log_path'             : sim_job.sim_log_file_path,
+        'dir_name'             : sim_job.results_dir_name,
         'test_name'            : sim_job.test,
         'seed'                 : sim_job.seed,
         'waves'                : sim_job.waves,
